@@ -31,12 +31,12 @@
 #include "file-utils.h"
 #include "fr-stock.h"
 #include "fr-window.h"
-#include "gconf-utils.h"
 #include "gtk-utils.h"
 #include "preferences.h"
 
 typedef struct {
 	FrWindow    *window;
+	GSettings   *settings;
 	GtkWidget   *dialog;
 	GtkWidget   *include_subfold_checkbutton;
 	GtkWidget   *add_if_newer_checkbutton;
@@ -59,6 +59,7 @@ static void
 open_file_destroy_cb (GtkWidget  *widget,
 		      DialogData *data)
 {
+	g_object_unref (data->settings);
 	g_free (data->last_options);
 	g_free (data);
 }
@@ -98,6 +99,7 @@ file_sel_response_cb (GtkWidget    *widget,
 	const char     *exclude_files;
 	const char     *exclude_folders;
 	char           *dest_dir;
+	char           *local_filename;
 
 
 	dlg_add_folder_save_last_options (data);
@@ -153,8 +155,9 @@ file_sel_response_cb (GtkWidget    *widget,
 	if (utf8_only_spaces (exclude_folders))
 		exclude_folders = NULL;
 
+	local_filename = g_filename_from_uri (selected_folder, NULL, NULL);
 	dest_dir = build_uri (fr_window_get_current_location (window),
-			      file_name_from_path (selected_folder),
+			      file_name_from_path (local_filename),
 			      NULL);
 
 	fr_window_archive_add_with_wildcard (window,
@@ -166,9 +169,10 @@ file_sel_response_cb (GtkWidget    *widget,
 					     update,
 					     follow_links);
 
+	g_free (local_filename);
 	g_free (dest_dir);
 	g_free (selected_folder);
-	
+
 	gtk_widget_destroy (data->dialog);
 
 	return TRUE;
@@ -182,7 +186,7 @@ include_subfold_toggled_cb (GtkWidget *widget,
 	DialogData *data = callback_data;
 
 	gtk_widget_set_sensitive (data->exclude_symlinks,
-				  GTK_TOGGLE_BUTTON (widget)->active);
+				  gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)));
 
 	return FALSE;
 }
@@ -207,9 +211,8 @@ add_folder_cb (GtkWidget *widget,
 	GtkWidget   *align;
 
 	data = g_new0 (DialogData, 1);
-
+	data->settings = g_settings_new (FILE_ROLLER_SCHEMA_ADD);
 	data->window = callback_data;
-
 	data->dialog = file_sel =
 		gtk_file_chooser_dialog_new (_("Add a Folder"),
 					     GTK_WINDOW (data->window),
@@ -502,14 +505,14 @@ dlg_add_folder_load_last_options (DialogData *data)
 	gboolean  recursive;
 	gboolean  no_symlinks;
 
-	base_dir = eel_gconf_get_string (PREF_ADD_CURRENT_FOLDER, "");
-	filename = eel_gconf_get_string (PREF_ADD_FILENAME, "");
-	include_files = eel_gconf_get_string (PREF_ADD_INCLUDE_FILES, "");
-	exclude_files = eel_gconf_get_string (PREF_ADD_EXCLUDE_FILES, "");
-	exclude_folders = eel_gconf_get_string (PREF_ADD_EXCLUDE_FOLDERS, "");
-	update = eel_gconf_get_boolean (PREF_ADD_UPDATE, FALSE);
-	recursive = eel_gconf_get_boolean (PREF_ADD_RECURSIVE, TRUE);
-	no_symlinks = eel_gconf_get_boolean (PREF_ADD_NO_SYMLINKS, FALSE);
+	base_dir = g_settings_get_string (data->settings, PREF_ADD_CURRENT_FOLDER);
+	filename = g_settings_get_string (data->settings, PREF_ADD_FILENAME);
+	include_files = g_settings_get_string (data->settings, PREF_ADD_INCLUDE_FILES);
+	exclude_files = g_settings_get_string (data->settings, PREF_ADD_EXCLUDE_FILES);
+	exclude_folders = g_settings_get_string (data->settings, PREF_ADD_EXCLUDE_FOLDERS);
+	update = g_settings_get_boolean (data->settings, PREF_ADD_UPDATE);
+	recursive = g_settings_get_boolean (data->settings, PREF_ADD_RECURSIVE);
+	no_symlinks = g_settings_get_boolean (data->settings, PREF_ADD_NO_SYMLINKS);
 
 	sync_widgets_with_options (data,
 			   	   base_dir,
@@ -626,14 +629,14 @@ dlg_add_folder_save_last_options (DialogData *data)
 				  &recursive,
 				  &no_symlinks);
 
-	eel_gconf_set_string (PREF_ADD_CURRENT_FOLDER, base_dir);
-	eel_gconf_set_string (PREF_ADD_FILENAME, filename);
-	eel_gconf_set_string (PREF_ADD_INCLUDE_FILES, include_files);
-	eel_gconf_set_string (PREF_ADD_EXCLUDE_FILES, exclude_files);
-	eel_gconf_set_string (PREF_ADD_EXCLUDE_FOLDERS, exclude_folders);
-	eel_gconf_set_boolean (PREF_ADD_UPDATE, update);
-	eel_gconf_set_boolean (PREF_ADD_RECURSIVE, recursive);
-	eel_gconf_set_boolean (PREF_ADD_NO_SYMLINKS, no_symlinks);
+	g_settings_set_string (data->settings, PREF_ADD_CURRENT_FOLDER, base_dir);
+	g_settings_set_string (data->settings, PREF_ADD_FILENAME, filename);
+	g_settings_set_string (data->settings, PREF_ADD_INCLUDE_FILES, include_files);
+	g_settings_set_string (data->settings, PREF_ADD_EXCLUDE_FILES, exclude_files);
+	g_settings_set_string (data->settings, PREF_ADD_EXCLUDE_FOLDERS, exclude_folders);
+	g_settings_set_boolean (data->settings, PREF_ADD_UPDATE, update);
+	g_settings_set_boolean (data->settings, PREF_ADD_RECURSIVE, recursive);
+	g_settings_set_boolean (data->settings, PREF_ADD_NO_SYMLINKS, no_symlinks);
 
 	g_free (base_dir);
 	g_free (filename);
